Generate Go functional options pattern for a type with has_default.
Returns: type definition + Option type + WithField functions + NewConfig constructor
Generate a PHP kwargs constructor for a type with has_default.
All fields become Option<T> parameters so PHP users can omit any field.
Assignments wrap non-Optional fields in Some() and apply defaults.
Generate a PyO3 #[new] constructor with kwargs for a type with has_default.
All fields become keyword args with their defaults in #[pyo3(signature = (...))].