convertible_types

Function convertible_types 

pub fn convertible_types(surface: &ApiSurface) -> AHashSet<String>
Build the set of types that can have binding→core From safely generated. Strict: excludes types with sanitized fields (lossy conversion). This is transitive: a type is convertible only if all its Named field types are also convertible (or are enums with From/Into support).