Module enums

Module enums 

Functions

enum_has_data_variants
Returns true if any variant of the enum has data fields. These enums cannot be represented as flat integer enums in bindings.
gen_enum
Generate an enum.
gen_pyo3_data_enum
Generate a PyO3 data enum as a #[pyclass] struct wrapping the core type.