pub fn has_unresolved_trait_methods(api: &ApiSurface) -> boolExpand description
Check if any type has methods from trait impls whose trait_source could not be resolved.
When true, the binding crate should add a glob import of the core crate (e.g.
use kreuzberg::*) to bring all publicly exported traits into scope.
This handles traits defined in private submodules that are re-exported.