Module methods

Module methods 

Functions

gen_constructor
Generate a constructor method.
gen_impl_block
Generate a full methods impl block (non-opaque types).
gen_method
Generate an instance method.
gen_opaque_impl_block
Generate a full impl block for an opaque type, delegating methods to self.inner.
gen_static_method
Generate a static method.
is_trait_method_name
Returns true when name matches a known trait method that would trigger clippy::should_implement_trait.