go_type_name

Function go_type_name 

pub fn go_type_name(name: &str) -> String
Apply Go acronym uppercasing to a name that is already in PascalCase (e.g. an IR type name).

IR type names come directly from Rust PascalCase (e.g. ImageUrl, JsonSchemaFormat). This function uppercases known acronym segments so they conform to Go naming conventions (e.g. ImageUrlImageURL, JsonSchemaFormatJSONSchemaFormat).