is_promoted_optional

Function is_promoted_optional 

pub fn is_promoted_optional(params: &[ParamDef], idx: usize) -> bool
Returns true if this parameter is required but must be promoted to optional because it follows an optional parameter in the list. PyO3 requires that required params come before all optional params.