pub fn input_type_names(surface: &ApiSurface) -> AHashSet<String>Expand description
Collect all Named type names that appear in the API surface — both as
function/method input parameters AND as function/method return types.
These are types that need binding→core From impls.
Return types need binding→core From impls because:
- Users may construct binding types and convert them to core types
- Generated code may use
.into()on nested Named fields in From impls - Round-trip conversion completeness ensures the API is fully usable
The result includes transitive dependencies: if ConversionResult is a
return type and it has a field metadata: HtmlMetadata, then HtmlMetadata
is also included.