Functions
- converter_
fn_ name - Return the converter function name for a given error type.
- gen_
csharp_ error_ types - Generate C# exception sub-classes for each error variant.
- gen_
ffi_ error_ codes - Generate a C enum of error codes plus an error-message function declaration.
- gen_
go_ error_ types - Generate Go sentinel errors and a structured error type for an
ErrorDef. - gen_
java_ error_ types - Generate Java exception sub-classes for each error variant.
- gen_
magnus_ error_ converter - Generate a converter function that maps a core error to
magnus::Error. - gen_
napi_ error_ converter - Generate a converter function that maps a core error to
napi::Error. - gen_
napi_ error_ types - Generate a
JsErrorenum with string constants for each error variant name. - gen_
php_ error_ converter - Generate a converter function that maps a core error to
PhpException. - gen_
pyo3_ error_ converter - Generate a
to_py_errconverter function that maps each Rust error variant to a Python exception. Uses Error-suffixed names for variant exceptions (N818 compliance). - gen_
pyo3_ error_ registration - Generate
m.add(...)registration calls for each exception type. Uses Error-suffixed names for variant exceptions (N818 compliance). Prefixes names that would shadow Python builtins (A004 compliance). - gen_
pyo3_ error_ types - Generate
pyo3::create_exception!macros for each error variant plus the base error type. Appends “Error” suffix to variant names that don’t already have it (N818 compliance). Prefixes names that would shadow Python builtins (A004 compliance). - gen_
rustler_ error_ converter - Generate a converter function that maps a core error to a Rustler error tuple
{:error, reason}. - gen_
wasm_ error_ converter - Generate a converter function that maps a core error to
JsValue. - magnus_
converter_ fn_ name - Return the Magnus converter function name for a given error type.
- napi_
converter_ fn_ name - Return the NAPI converter function name for a given error type.
- php_
converter_ fn_ name - Return the PHP converter function name for a given error type.
- python_
exception_ name - Return the Python exception name for a variant, avoiding shadowing of Python builtins.
- rustler_
converter_ fn_ name - Return the Rustler converter function name for a given error type.
- wasm_
converter_ fn_ name - Return the WASM converter function name for a given error type.