pub fn gen_magnus_error_methods_struct(
error: &ErrorDef,
core_import: &str,
) -> StringExpand description
Generate a Magnus-wrapped Rust struct that stores the whitelisted error introspection method return values and exposes them as Ruby instance methods.
Returns an empty string when error.methods is empty.