Module functions

Module functions 

Functions

collect_explicit_core_imports
Collect explicit type and enum names from the API surface for named imports.
collect_trait_imports
Collect all unique trait import paths from types’ methods.
gen_function
Generate a free function.
has_unresolved_trait_methods
Check if any type has methods from trait impls whose trait_source could not be resolved.