Functions
- collect_
explicit_ core_ imports - Collect explicit type and enum names from the API surface for named imports.
- collect_
trait_ imports - Collect all unique trait import paths from types’ methods.
- gen_
function - Generate a free function.
- has_
unresolved_ trait_ methods - Check if any type has methods from trait impls whose trait_source could not be resolved.