pub fn collect_trait_imports(api: &ApiSurface) -> Vec<String>Expand description
Collect all unique trait import paths from types’ methods.
Returns a deduplicated, sorted list of trait paths (e.g. ["liter_llm::LlmClient"])
that need to be imported in generated binding code so that trait methods can be called.
Both opaque and non-opaque types are scanned because non-opaque wrapper types also
delegate trait method calls to their inner core type.