pub fn gen_opaque_impl_block(
typ: &TypeDef,
mapper: &dyn TypeMapper,
cfg: &RustBindingConfig<'_>,
opaque_types: &AHashSet<String>,
mutex_types: &AHashSet<String>,
adapter_bodies: &AdapterBodies,
) -> StringExpand description
Generate a full impl block for an opaque type, delegating methods to self.inner.
opaque_types is the set of type names that are opaque wrappers (use Arc<inner>).
This is needed so that return-type wrapping uses the correct pattern for cross-type returns.
mutex_types is the subset of opaque types whose inner field uses Arc<Mutex<T>>;
method dispatch uses .lock().unwrap() for these types.