pub fn csharp_type_name(name: &str) -> StringExpand description
Apply initialism uppercasing to a name that is already in PascalCase (e.g. an IR type name).
IR type names come directly from Rust PascalCase (e.g. GraphQLRouteConfig, ImageUrl).
When such names have been processed by heck::ToPascalCase they may lose initialism
capitalisation (e.g. GraphQLRouteConfig → GraphQlRouteConfig). This function restores
the canonical form regardless of whether the input is already correct or heck-corrupted.
Examples:
GraphQlRouteConfig→GraphQLRouteConfigGraphQLRouteConfig→GraphQLRouteConfig(idempotent)HttpStatus→HTTPStatus