pub fn is_delegatable_type(ty: &TypeRef) -> boolExpand description
A type is delegatable if it can cross the binding boundary without From impls. Named types are NOT delegatable as function params (may lack From impls). For opaque methods, Named types are handled separately via Arc wrap/unwrap.